@@ -1,4 +1,4 @@
-/* $Id: auth.c,v 1.25 2006/01/10 12:49:14 ichiro Exp $ */
+/* $Id: auth.c,v 1.29 2006/02/12 19:00:25 ichiro Exp $ */
 /*
  * Copyright (c) 2004, 2005, 2006
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -51,10 +51,10 @@
 extern int debug;
 
 #include "kircd.h"
-#include "httpd.h"
+#include "auth.h"
 
-void print_easybutton(struct tparam *);
 void print_error_IE(struct tparam *);
+extern int send_msg(int, struct tparam *, char *, char *);
 
 int auth_proc(int socket, struct tparam *th2, char *buf, char *header)
 {
@@ -64,7 +64,6 @@ int auth_proc(int socket, struct tparam *th2, char *buf, char *header)
 	char message[IRC_MAX];
 	char base64[IRC_MAX * 2];
 	char buffer[IRC_MAX * 2];
-	char buffer2[IRC_MAX * 2];
 	char web_user[AUTH_LEN], web_pass[AUTH_LEN];
 	char cookie_user[AUTH_LEN], cookie_pass[AUTH_LEN];
 	char date_str[CDATE_LEN];
@@ -135,7 +134,7 @@ int auth_proc(int socket, struct tparam *th2, char *buf, char *header)
 		    } /* USE_COOKIE */
 	    } else {
 			DPRINTF(1, ("DEBUG: cannot auth\n"));
-			send_msg(socket, th2, http_auth_401_header);
+			send_msg(socket, th2, http_auth_401_header, "");
 			return -1;
 	    }
 	} else if (th2->auth_method == 2) { /* Easy Access */
@@ -144,7 +143,7 @@ int auth_proc(int socket, struct tparam *th2, char *buf, char *header)
 		DPRINTF(1, ("DEBUG: in first show easy auth page\n"));
 		print_easybutton(th2);
 		/* send data */
-		send_msg(socket, th2, header);
+		send_msg(socket, th2, header, "easy auth");
 		/* break */
 		return -1;
 	    }
@@ -160,9 +159,9 @@ void print_easybutton(struct tparam *th2)
 	if (!th2->regist_done) { /* show user/pass text box until regist */
         	send_buf(th2, "Easy Access Registration<br>");
 		send_buf(th2,
-		 "user<input type=\"text\" name=\"user2\" size=\"10\"><br>");
+		 "user<input type=\"text\" istyle=3 name=\"user2\" size=\"10\"><br>");
 		send_buf(th2,
-		 "pass<input type=\"password\" name=\"pass2\" size=\"10\"><br>");
+		 "pass<input type=\"password\" istyle=3 name=\"pass2\" size=\"10\"><br>");
 	} else
 		send_buf(th2, "Push Button<br>");
 
@@ -170,9 +169,9 @@ void print_easybutton(struct tparam *th2)
 		 "<input type=\"submit\" value=\"EasyAccess\"></form>");
 }
 
-int easy_regist(int socket, struct tparam *th2, char *buf, char *header)
+int easy_regist(int socket, struct tparam *th2, char *buf)
 {
-	int post_length;
+	int post_length = 0;
 	char web_user[AUTH_LEN], web_pass[AUTH_LEN];
 	char uid[AUTH_LEN];
 	char *s;
@@ -207,7 +206,7 @@ int easy_regist(int socket, struct tparam *th2, char *buf, char *header)
 		post_length = atoi(s + 16);
 
 	buffer = (char*)malloc(post_length + 1);
-	if (buffer == NULL) return;
+	if (buffer == NULL) return -1;
 	*buffer = '\0';
 
 	/* if cannot read post data , read more */
@@ -302,17 +301,19 @@ int check_timeout(struct tparam *th2)
 	struct tm *date;
 	char date_str[CDATE_LEN];
 
-	if (!th2->last_access) {
-		time(&timer);
+	/* get time */
+	time(&timer);
+
+	/* initialize */
+	if (!th2->last_access)
 		th2->last_access = timer;
-	}
+
 	/* make Last access time */
 	date = gmtime(&th2->last_access); 
 	strftime(date_str, 255, "%a, %d-%b-%Y %H:%M:%S GMT", date); 
 	DPRINTF(1, ("DEBUG: Last Access Time: %s\n", date_str));
  
 	/* update access time and calc time difference */
-	time(&timer); 
 	diff = timer - th2->last_access;
 	th2->last_access = timer;
 	date = gmtime(&th2->last_access);
