@@ -1,4 +1,4 @@
-/* $Id: decode.c,v 1.38 2006/01/09 17:18:08 ichiro Exp $ */
+/* $Id: decode.c,v 1.47 2006/06/05 02:40:39 ichiro Exp $ */
 /*
  * Copyright (c) 2004, 2005, 2006
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -37,7 +37,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <ctype.h>
-#include <errno.h>
 #include <sys/types.h>
 #include <regex.h>
 #include <sys/socket.h>
@@ -66,7 +65,7 @@ int charconv(char *dst, size_t dst_len, const char *src, size_t src_len, const c
 	const char *p_in;
 	char *p_out;
 
-	p_in = src;
+	p_in  = src;
 	p_out = dst;
 
 	ic = iconv_open(to, from);
@@ -78,19 +77,25 @@ int charconv(char *dst, size_t dst_len, const char *src, size_t src_len, const c
 	}
 
 	/* iconv() */
-	DPRINTF(0, ("%s(%s) ->(%s)\n", src, from, to));
 	result = iconv(ic, &p_in, &src_len, &p_out, &dst_len);
-	if (result == (size_t)(-1))
-		printf("errno %d: iconv() %s -> %s\n", errno, from, to);
+	if (result == (size_t)(-1)) {
+		/* print src dst */
+		DPRINTF(1, ("errno %d iconv:<%s>(",
+				errno, from));
+		for (i = 0; i < strlen(src); *src++)
+			DPRINTF(1, ("%02x", (unsigned char)src[i]));
+		DPRINTF(1, (")\n"));
+	} else {
+		/* print src dst */
+		DPRINTF(1, ("iconv:[%s]<%s>(", src, from));
+		for (i = 0; i < strlen(src); *src++)
+			DPRINTF(1, ("%02x", (unsigned char)src[i]));
 
-	/* print src dst */
-	DPRINTF(1, ("iconv:[%s]\n<%s>(", src, from));
-	for (i = 0; i < strlen(src); *src++)
-		DPRINTF(1, ("%02x", (unsigned char)src[i]));
-	DPRINTF(1, (") ->\n<%s>(", to));
-	for (i = 0; i < strlen(dst); *dst++)
-		DPRINTF(1, ("%02x", (unsigned char)dst[i]));
-	DPRINTF(1, (")\n"));
+		DPRINTF(1, (") -><%s>(", to));
+		for (i = 0; i < strlen(dst); *dst++)
+			DPRINTF(1, ("%02x", (unsigned char)dst[i]));
+		DPRINTF(1, (")\n"));
+	}
 
 	iconv_close(ic);
 
@@ -99,13 +104,14 @@ int charconv(char *dst, size_t dst_len, const char *src, size_t src_len, const c
 
 int url_decode_jis(char *src, int phone_type)
 {
-	int n, j;
+	int n;
 	int len = 0;
-	int count = 0;
+	int count_ascii = 0;
 	char *p;
 
 	const char *q;
 	size_t in_len, out_len;
+	int sum;
 	unsigned char data[IRC_MAX * 2];
 	out_len = sizeof(data);
 
@@ -116,21 +122,19 @@ int url_decode_jis(char *src, int phone_type)
 		return (1);
 
 	/* URL convert to raw data */
-	url_decode_rawdata(data, src);
-
-	/* emoji encode */
-	len = emoji_encode(data, phone_type);
+	len = url_decode_rawdata(data, src);
 	q = data;
 	in_len = len + 1;
 
-	/* check encode method */
+	/* charconv to cp932 */
 	for (n = 0; n < len; n++) {
 		if (data[n] == 0x1B) { /* found JIScode */
 			DPRINTF(1, ("found JIS\n"));
-			strcpy(p, data);
-			return (0);
+			charconv(p, out_len, q, in_len, "MS_KANJI", "iso-2022-jp");
+			goto emoji_start;
 		}
 
+#if 0
 		count = 0;
 		if (data[n] >= 0xC0 && data[n] <= 0xF7) {
 			if (data[n] >= 0xC0 &&
@@ -144,35 +148,42 @@ int url_decode_jis(char *src, int phone_type)
 				count = 3;
 			}
 			for (j = 0; j < count; j++) {
-				if (data[n+1] < 0x80 ||
-				    data[n+1] > 0xBF)
+				if (data[n+j+1] < 0x80 ||
+				    data[n+j+1] > 0xBF)
 					goto OUT; /* not UTF-8 */
 			}
 			DPRINTF(1, ("found UTF-8\n"));
-			charconv(p, out_len, q, in_len, "iso-2022-jp", "utf-8");
-			return (0);
+			charconv(p, out_len, q, in_len, "MS_KANJI", "utf-8");
+			goto emoji_start;
 		}
 OUT:
+#endif
 
+		sum = data[n] << 8 | data[n + 1];
 		if (data[n] < 0x80) { 
+			count_ascii++;
 			goto loop_end;
 		} else if (data[n] >= 0x81 && data[n] <= 0x9F) {
 			DPRINTF(1, ("found CP932\n"));
-			charconv(p, out_len, q, in_len, "iso-2022-jp", "cp932");
-			return (0);
+			strcpy(p, data);
+			goto emoji_start;
 		} else if (data[n] >= 0xA1 && data[n] <= 0xDF) {
 			if ((data[n+1] < 0x80) ||
 			    (data[n+1] > 0x80 && data[n+1] < 0xA0)) {
 				DPRINTF(1, ("found CP932\n"));
-				charconv(p, out_len, q, in_len, "iso-2022-jp", "cp932");
-				return (0);
+				strcpy(p, data);
+				goto emoji_start;
 			}
+		} else if (sum >= 0xF340 && sum <= 0xF9FC) {
+			DPRINTF(1, ("found emoji\n"));
+				strcpy(p, data);
+				goto emoji_start;
 		}
 
 		if (data[n] >= 0xF0 && data[n] <= 0xFE) {
 			DPRINTF(1, ("found EUC\n"));
-			charconv(p, out_len, q, in_len, "iso-2022-jp", "euc-jp");
-			return (0);
+			charconv(p, out_len, q, in_len, "MS_KANJI", "euc-jp");
+			goto emoji_start;
 		} else { 
 			n++;
 		}
@@ -180,25 +191,39 @@ OUT:
 		if ((data[n] >= 0x40 && data[n] <= 0x7E) || 
 		    (data[n] >= 0x80 && data[n] <= 0xA0)) {
 			DPRINTF(1, ("found CP932\n"));
-			charconv(p, out_len, q, in_len, "iso-2022-jp", "cp932");
-			return (0);
+			strcpy(p, data);
+			goto emoji_start;
 		} else if (data[n] >= 0xFD && data[n] <= 0xFE) {
 			DPRINTF(1, ("found EUC\n"));
-			charconv(p, out_len, q, in_len, "iso-2022-jp", "euc-jp");
-			return (0);
+			charconv(p, out_len, q, in_len, "MS_KANJI", "euc-jp");      
+			goto emoji_start;
 		}
 loop_end:
 	;;
 	}
 
-	strcpy(src, q);
+	/* skip charconv for all ascii text */
+	if (len == count_ascii) {
+		strcpy(p, data);
+		return (0);
+	}
+
+emoji_start:
+	/* emoji encode */
+	len = emoji_encode(p, phone_type);
+
+	in_len = len + 1;
+	strcpy(data, p);
+
+	/* charconv cp932 -> iso2022jp */
+	charconv(p, out_len, q, in_len, "iso-2022-jp", "MS_KANJI");
 
 	return (0);
 }
 
 int decode_jis2cp932(char *src)
 {
-	int n, i, len;
+	int n, len;
 	char *p;
 	const char *q;
 	size_t in_len, out_len;
@@ -216,7 +241,7 @@ int decode_jis2cp932(char *src)
 	for (n = 0; n < len; n++) {
 		if (src[n] == 0x1B) { /* found JIScode */
 			DPRINTF(1, ("decode_jis2cp932()\n"));
-			charconv(p, out_len, q, in_len, "cp932", "iso-2022-jp");
+			charconv(p, out_len, q, in_len, "MS_KANJI", "iso-2022-jp");
 			return (0);
 		}
 	}
@@ -317,7 +342,7 @@ int channel_decode(char *dst, char *src)
 
 	/* CP932 -> ISO-2022-JP */
 	in_len = strlen(dst2) + 1;
-	charconv(out, out_len, in, in_len, "iso-2022-jp", "cp932");
+	charconv(out, out_len, in, in_len, "iso-2022-jp", "MS_KANJI");
 
 	return (0);
 }
@@ -347,7 +372,7 @@ int channel_encode(char *dst, char *src)
 
 	/* ISO-2022-JP -> CP932 */
 	in_len = strlen(dst2) + 1;
-	charconv(out, out_len, in, in_len, "cp932", "iso-2022-jp");
+	charconv(out, out_len, in, in_len, "MS_KANJI", "iso-2022-jp");
 
 	return (0);
 }
