@@ -1,4 +1,4 @@
-/* $Id: httpd.c,v 1.90 2006/01/10 13:52:47 ichiro Exp $ */
+/* $Id: httpd.c,v 1.101 2006/12/20 13:33:53 ichiro Exp $ */
 /*
  * Copyright (c) 2004, 2005, 2006
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -55,9 +55,10 @@ extern int debug;
 
 void httpd_proc(struct tparam *, int);
 int auth_proc(int, struct tparam *, char *, char *);
-int easy_regist(int, struct tparam *, char *, char *);
 void print_command_page(struct tparam *);
 
+extern int send_msg(int, struct tparam *, char *, char *);
+extern int easy_regist(int, struct tparam *, char *);
 extern int check_timeout(struct tparam *);
 extern int check_agent(struct tparam *, char *);
 
@@ -76,7 +77,7 @@ httpd(gpointer param)
 			printf("error: accepting a socket.\n");
 			exit (1);
 		}
-		usleep(100000);
+		usleep(1000000);
 		httpd_proc(th2, s3);
 
 		close(s3);
@@ -85,9 +86,6 @@ httpd(gpointer param)
 
 void httpd_proc(struct tparam *th2, int socket)
 {
-	time_t timer;
-	struct tm *date;
-	
 	char buf[SBUFLEN];
 	char meth_name[M_LEN];
 	char channel[C_NAME], channel2[C_NAME];
@@ -103,7 +101,6 @@ void httpd_proc(struct tparam *th2, int socket)
 	char subtopic[SUBTOPIC_LEN];
 
 	int n = 0;
-	int r_fd = 0;
 	char http_ver[4];
 
 	int number = 0;
@@ -113,6 +110,9 @@ void httpd_proc(struct tparam *th2, int socket)
 	int post_length = 0;
 	int post_ch_number = 0;
 
+	/* timer */
+	long timer, diff;
+
 	/* bzero */
 	bzero(buf, sizeof(buf));
 	bzero(meth_name, sizeof(meth_name));
@@ -129,9 +129,30 @@ void httpd_proc(struct tparam *th2, int socket)
 	bzero(cmd_buf, sizeof(cmd_buf));
 	bzero(subtopic, sizeof(subtopic));
 
+	/* init header */
+	strcpy(header, http_header0);
+
+	/* newversion available check */
+        /* check time */
+        time(&timer);
+        diff = timer - th2->last_check;
+        DPRINTF(0, ("diff = %d\n", (int)diff));
+
+        if ((diff > VC_INT * 60 * 60) ||
+	    (th2->new_available < 0)) {
+                /*  interval time(s) = VC_INT(h)*60*60 */
+                th2->last_check = timer;
+		n = version_check(th2, VERSION);
+		if (n == 0) {
+			DPRINTF(0,("new_available=%x\n", th2->new_available));
+			} else {
+			DPRINTF(0,("version_check() = %d\n", n));
+		}
+	}
+
 	/* get buffer from stream */
 	if (read(socket, buf, SBUFLEN) <= 0 ) {
-		printf("error: reading a request.\n");
+		printf("error: reading a socket in httpd_proc()\n");
 		return;
 	}
 
@@ -146,15 +167,12 @@ void httpd_proc(struct tparam *th2, int socket)
 	DPRINTF(2, ("------------------\n"));
 	DPRINTF(2, ("BUF:%s\n--------------\n", buf));
 
-	/* init header */
-	strcpy(header, http_header0);
-
 	/* check user-agent (Easy access) */
 	if ((th2->auth_method == 2) && /* Easy Access */
 	    (check_agent(th2, buf) < 0)) {
 		DPRINTF(0, ("error: Detect PC browser\n"));
 		 /* send data */
-		send_msg(socket, th2, header);
+		send_msg(socket, th2, header, "error");
 		return;
 	} else if ((th2->auth_method == 0) || (th2->auth_method == 1)) {
 		strcpy(uid, find_uid(buf));
@@ -171,6 +189,15 @@ void httpd_proc(struct tparam *th2, int socket)
 			th2->phone_carrier, uid));
 	}
 
+	/* check buffer (for AU) */
+	if ((th2->phone_carrier == AU_EZWEB) &&
+ 	    (!strstr(buf, "Connection:"))) {
+		send_buf(th2, "server error...");
+		send_buf(th2, "Please reconnect.");
+		send_msg(socket, th2, header, "error");
+		return;
+	}
+
 	/* check timeout */
 	if ((th2->auth_method == 2) && /* Easy Access */
 	    (check_timeout(th2) < 0) &&
@@ -198,7 +225,7 @@ void httpd_proc(struct tparam *th2, int socket)
 
 		/* show auth page */
 		print_easybutton(th2);
-		send_msg(socket, th2, header);
+		send_msg(socket, th2, header, "auth");
 		return;
 	}
 
@@ -213,7 +240,7 @@ post_start:
 		    DPRINTF(0, ("EasyAccess registration page,%d,%d\n",
 				th2->regist_done, th2->auth_flag));
 		    if (!th2->regist_done || !th2->auth_flag) {
-			if (easy_regist(socket, th2, buf, header) < 0) {
+			if (easy_regist(socket, th2, buf) < 0) {
 			    DPRINTF(0, ("EasyAccess registration Failed\n"));
 			}
 		    }
@@ -483,7 +510,7 @@ index_start:
 
 		send_buf(th2,
 			"<hr><a accesskey=\"9\" href=\"/\">back[9]</a>");
-		send_msg(socket, th2, header);
+		send_msg(socket, th2, header, "users list");
 		return;
 	    }
 
@@ -497,7 +524,7 @@ index_start:
 
 		send_buf(th2,
 			"<hr><a accesskey=\"9\" href=\"/\">back[9]</a>");
-		send_msg(socket, th2, header);
+		send_msg(socket, th2, header, "users");
 
 		return;
 	    }
@@ -510,7 +537,7 @@ index_start:
 			"Topic:%s<br>", th2->topic[subusernum]);
 		send_buf(th2, message);
 
-		send_msg(socket, th2, header);
+		send_msg(socket, th2, header, "topic");
 
 		return;
 	    }
@@ -522,7 +549,7 @@ command_start:
 		print_command_page(th2);
 
 		/* send data */
-		send_msg(socket, th2, header);
+		send_msg(socket, th2, header, "command");
 
 		return;
 	    }
@@ -577,7 +604,7 @@ command_start:
 		}
 		th2->read_count[number] = th2->history_count[number];
 
-		send_msg(socket, th2, header);
+		send_msg(socket, th2, header, th2->name[number]);
 
 		update = 0;
 
@@ -618,7 +645,16 @@ command_start:
 		    "<br>kircd Ver %s", VERSION);
 		send_buf(th2, message);
 
-		send_msg(socket, th2, header);
+		if (th2->new_available) {
+			sprintf(message,
+			    "<br>new version (%d.%d.%d) available",
+			    (th2->new_available >> 16) & 0xff,
+			    (th2->new_available >> 8) & 0x00ff,
+			    (th2->new_available) & 0x0000ff);
+			send_buf(th2, message);
+		}
+
+		send_msg(socket, th2, header, "KIRCD");
 
 		return;
 	    }
@@ -630,7 +666,7 @@ command_start:
 		    th2->auth_flag = 0;
 
 		    send_buf(th2, "logout done...");
-		    send_msg(socket, th2, header);
+		    send_msg(socket, th2, header, "logout");
 
 		    return;
 		}
@@ -642,7 +678,7 @@ command_start:
 
 		    send_buf(th2, "logoff done...");
 		    send_buf(th2, "Please register again.");
-		    send_msg(socket, th2, header);
+		    send_msg(socket, th2, header, "logoff");
 
 		    return;
 		}
@@ -658,23 +694,30 @@ void send_buf(struct tparam *th, char *addmsg)
 	add_len = strlen(addmsg);
 
 	if (th->send_buflen < (buf_len + add_len + 1)) {
-		DPRINTF(1, ("SEND_BUF %d -> ", th->send_buf));
+		DPRINTF(1, ("SEND_BUF LENGTH %d -> ", th->send_buflen));
 		th->send_buflen = th->send_buflen + HTTPBUF;
 		th->send_buf = (char *)realloc(th->send_buf,
 				th->send_buflen);
-		DPRINTF(1, ("%d\n", th->send_buf));
+		DPRINTF(1, ("%d\n", th->send_buflen));
 	}
 
 	strcat(th->send_buf, addmsg);
 }
 
-int send_msg(int fd, struct tparam *th, char *header_msg)
+int send_msg(int fd, struct tparam *th, char *header_msg, char *addheader)
 {
-	int n;
 	int header_len, msg_len, footer_len, total_len;
 	int buffer_len;
 	char contentlen[30];
 	char *buffer;
+	char http_header1[512];
+
+	/* make header with title */
+	sprintf(http_header1,
+		"<html>\r\n<head>\r\n"
+		"<title>%s</title>\r\n</head>\r\n"
+		"<body>\r\n",
+		addheader);
 
 	header_len = strlen(http_header1);
 	msg_len    = strlen(th->send_buf);
@@ -814,13 +857,16 @@ int send_part(struct tparam *th, char *channel)
 {
 	char channel2[C_NAME];
 
-	DPRINTF(0, ("send_part()\n"));
+	DPRINTF(0, ("send_part(%s)\n", channel));
 
 	if (channel[0] == '%') {	/* disconnect from irc-channel */
 		/* any -> #hoge*.jp */
 		channel_decode(channel2, channel);
 		sprintf(th->postdata, ":%s PART %s\r\n",
 			th->real_nickname, channel2);
+	} else if (channel[0] == '#') {	/* disconnect from irc-channel */
+		sprintf(th->postdata, ":%s PART %s\r\n",
+			th->real_nickname, channel);
 	} else {			/* disconnect from person */
 		/* any ->%hoge(CP932) */
 		channel_encode(channel2, channel);
