@@ -1,6 +1,6 @@
-/* $Id: httpd.h,v 1.5 2005/12/16 17:55:25 ichiro Exp $ */
+/* $Id: httpd.h,v 1.14 2006/02/12 19:00:25 ichiro Exp $ */
 /*
- * Copyright (c) 2004
+ * Copyright (c) 2004, 2005, 2006
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
  * All rights reserved.
  *
@@ -37,26 +37,18 @@ static char http_header0[] = {
 };
 
 static char http_contype[] = {
-	"Content-Type: text/html; charset=ISO-2022-JP\r\n"
-};
-
-static char http_header1[] = {
-	"<html>\r\n<head>\r\n"
-	"<title>kircd</title>\r\n</head>\r\n"
-	"<body>\r\n"
+	"Content-Type: text/html; charset=Shift-JIS\r\n"
+	"Pragma: no-cache\r\n"
+	"Cache-control: no-cache\r\n"
 };
 
+#if 0
 static char ico_header10[] = {
 	"Content-type: image/x-icon\r\n"
 	"\r\n"
 };
+#endif
 
 static char http_footer[] = {
 	"\r\n</body></html>\r\n"
 };
-
-static char http_auth_401_header[] = {
-	"HTTP/1.1 401 Access Denied\r\n"
-	"WWW-Authenticate: Basic realm=\"KIRCD\"\r\n"
-	"Content-type: text/html\r\n"
-};
