@@ -1,4 +1,4 @@
-/* $Id: keitai.c,v 1.64 2006/01/09 19:07:53 ichiro Exp $ */
+/* $Id: keitai.c,v 1.73 2006/02/12 19:00:25 ichiro Exp $ */
 /*
  * Copyright (c) 2004, 2005, 2006
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -53,6 +53,10 @@ extern int debug;
 #include <iconv.h>
 #endif
 
+#ifndef _LIBICONV_VERSION
+#define _LIBICONV_VERSION 0x0
+#endif
+
 int
 keitai_start(struct tparam *th)
 {
@@ -116,11 +120,6 @@ int priv_recv(struct tparam *th)
 	int ch_number = 255; /* 255 means "not found" */
 	tm = localtime(&t);
 
-	/* iconv */
-	const char *p_in;
-	char *p_out;
-	size_t in_len, out_len;
-
 	/* zero clear */
 	bzero(channel,  sizeof(channel));
 	bzero(channel2, sizeof(channel2));
@@ -240,8 +239,10 @@ int ctcp_recv(struct tparam *th, char *id, char *message)
 		   #2: client version
 		   #3: env of client */
 		sprintf(data,
-		    ":%s NOTICE %s :%cVERSION %s %s %c\r\n",
-		    th->real_nickname, id, 0x01, PACKAGE, VERSION, 0x01);
+		    ":%s NOTICE %s :%cVERSION %s %s+ICONV %d.%d %c\r\n",
+		    th->real_nickname, id, 0x01, PACKAGE,
+		    VERSION, (_LIBICONV_VERSION >> 8),
+		    (_LIBICONV_VERSION & 0x00ff), 0x01);
 	}
 
 	/* transfer message */
@@ -293,11 +294,6 @@ int topic_recv(struct tparam *th)
 	char topic[IRC_MAX * 2], buf[IRC_MAX * 2];
 	char channel[C_NAME], channel2[C_NAME];
 
-	/* iconv */
-	const char *p_in;
-	char *p_out;
-	size_t in_len, out_len;
-
 	/* zero clear */
 	bzero(buf, sizeof(buf));
 	bzero(channel, sizeof(channel));
@@ -345,14 +341,14 @@ int part_recv(struct tparam *th)
 	bzero(channel2, sizeof(channel2));
 
 	/* get PART */
-	if (sscanf(th->l_buff, ":%[^!]!%*s PART %s :%*[^,]",
+	if (sscanf(th->l_buff, ":%[^!]!%*s PART %s :%*[^\r\n]",
 		id, channel) == 2) {
 		if (strcmp2(th->real_nickname, id) != 0) {
 		   /* send NAMES command */
 		   send_names(th, channel);
 		   return (0);
 		}
-	} else if (sscanf(th->l_buff, ":%s PART %s :%*[^,]",
+	} else if (sscanf(th->l_buff, ":%s PART %s :%*[^\r\n]",
 		id, channel) == 2) {
 		if (strcmp2(th->real_nickname, id) != 0) {
 			return (0);
@@ -443,12 +439,15 @@ int join_recv(struct tparam *th)
 
 	/* get JOIN */
 	if (strstr(th->l_buff, "JOIN")) {
-		if (sscanf(th->l_buff, ":%[^!]!%*s JOIN :%[^,]",
+		if (sscanf(th->l_buff, ":%[^!]!%*s JOIN :%[^\r\n]",
 			   id, channel) == 2);
-		else if (sscanf(th->l_buff, ":%[^!]!%*s JOIN %[^,]",
+		else if (sscanf(th->l_buff, ":%[^!]!%*s JOIN %[^\r\n]",
 				id, channel) == 2);
-		else if (sscanf(th->l_buff, ":%s JOIN %[^,]",
+		else if (sscanf(th->l_buff, ":%s JOIN %[^\r\n]",
 				id, channel) == 2);
+	/* madoka hack (delete space(0x20) charactor) */
+	if (channel[strlen(channel) - 1] == 0x20)
+		channel[strlen(channel) - 1] = 0x0;
 
 		if (strcmp2(th->real_nickname, id) == 0) {
 			/* channel;  #hoge:*.jp -> %hoge(CP932) */
@@ -473,7 +472,7 @@ int join_recv(struct tparam *th)
 
 int channel_make(struct tparam *th, char *channel)
 {
-	int i, n = 0;
+	int n = 0;
 
 	/* make new channel */
 	while (th->name[n][0] != '\0')
@@ -513,7 +512,7 @@ int nick_recv(struct tparam *th)
 	char old_nickname[NAME_LEN];
 	char new_nickname[NAME_LEN];
 
-	sscanf(th->l_buff, ":%[^!]!%*s NICK :%[^,]",
+	sscanf(th->l_buff, ":%[^!]!%*s NICK :%[^\r\n]",
 		old_nickname, new_nickname);
 
 	if (strcmp2(th->real_nickname, old_nickname) == 0) {
@@ -530,9 +529,10 @@ int send_names(struct tparam *th, char *channel)
 {
 	char data[IRC_MAX];
 
-	sprintf(data, "NAMES %s\r\n", channel);
+	sprintf(data, "NAMES %s\n", channel);
 
-	DPRINTF(0, ("NAMES:sent data\n"));
+	DPRINTF(0, ("NAMES:sent data(%s)(ch_len:%d)\n",
+			data, strlen(channel)));
 
 	send_postdata(th->socket_number, data);
 
