@@ -1,4 +1,4 @@
-/* $Id: kircd.h,v 1.58 2006/01/09 19:08:07 ichiro Exp $ */
+/* $Id: kircd.h,v 1.68 2006/12/20 13:04:37 ichiro Exp $ */
 /* #define DEBUG */
 /*
  * Copyright (c) 2004, 2005, 2006
@@ -32,6 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -51,15 +52,20 @@
 #define CLIENT 0
 #define SERVER 1
 
-#define SBUFLEN 8192
-#define LBUFLEN 8192
-#define HTTPBUF 8192
+/* length of hostname and portnumber */
+#define HOSTNAME_LEN 128
+#define PORT_LEN 10
+
+/* buffer size */
+#define SBUFLEN 16384
+#define LBUFLEN 16384
+#define HTTPBUF 16384
 
 #define CONFSEP ";\n"
 
 /* GET /channel?? HTTP/1.1 */
-/* GET/POST len 5 */
-/* channel?? len 10 */
+/* GET/POST    ----> length 5 */
+/* channel??   ----> length 10 */
 #define M_LEN 5
 #define URI_LEN 10
 
@@ -80,10 +86,11 @@
 /* max cache line */
 #define C_HISTORY_NUM 31
 
-/* max length of nickname */
+/* max length of name */
+#define REALNAME_LEN 64
 #define NAME_LEN 10
 
-/* rfc1459, max length of IRC message is 512 byte */
+/* max length of IRC message */
 #define IRC_MAX 1000
 
 /* subtopic length */
@@ -99,16 +106,17 @@
 #define D_STR   3
 #define AU_STR  4
 
-/* CTCP */
-static char ctcp_clientinfo[] = {
-        "CLIENTINFO VERSION\r\n"
-};
+/* version check */
+#define VC_HOST "cvs.sourceforge.jp"
+#define VC_PORT "80"
+#define VC_URI "/cgi-bin/viewcvs.cgi/*checkout*/kircd/kircd/configure.in"
+#define VC_INT 6
 
 struct tparam {
 	int socket_number;
 	int server_socket;
 
-	char real_nickname[40];
+	char real_nickname[REALNAME_LEN];
 
 	/* recieve buffer */
 	int s_read;
@@ -160,15 +168,19 @@ struct tparam {
 	/* timer */
 	time_t last_access;
 	time_t timeout;
+
+	/* new version check */
+	int new_available;
+	time_t last_check;
 };
 
 struct config {
-	char hostname[128];
-	char server_port[40];
-	char client_port[40];
-	char password[40];
-	char username[40];
-	char nickname[40];
+	char hostname[HOSTNAME_LEN];
+	char server_port[PORT_LEN];
+	char client_port[PORT_LEN];
+	char password[REALNAME_LEN];
+	char username[REALNAME_LEN];
+	char nickname[REALNAME_LEN];
 
 	/* auth */
 	char auth_user[AUTH_LEN];
@@ -196,7 +208,6 @@ gpointer lineget(gpointer);
 extern gpointer httpd(gpointer);
 
 extern int send_postdata(int, char *);
-extern int send_msg(int, struct tparam *, char *);
 extern void send_buf(struct tparam *, char *);
 extern int readconf(unsigned char *, struct config *);
 extern int keitai_start(struct tparam *);
@@ -218,7 +229,8 @@ extern int send_part(struct tparam *, char *);
 extern int url_decode_jis(char *, int);
 extern int decode_jis2cp932(char *);
 
-extern int charconv(char *, size_t, const char *, size_t, const char *, const char *);
+extern int charconv(char *, size_t, const char *,
+	size_t, const char *, const char *);
 extern int channel_encode(char *, char *);
 extern int channel_decode(char *, char *);
 extern int ltgt_encode(char *, char *);
@@ -227,4 +239,7 @@ extern char * href_conv(char *);
 extern int strcmp2(char *, char *);
 extern int count_user(char *);
 
+extern void print_easybutton(struct tparam *);
 extern char* find_uid(char *);
+
+extern int version_check(struct tparam *, char *);
