@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.28 2006/01/10 13:52:47 ichiro Exp $ */
+/* $Id: main.c,v 1.38 2006/12/20 13:25:56 ichiro Exp $ */
 /*
  * Copyright (c) 2004, 2005, 2006
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -52,7 +52,6 @@ int debug = 3;
 #include "kircd.h"
 
 unsigned char *configfile = "kircd.conf";
-static char version[]= VERSION;
 
 char buff[SBUFLEN+1];
 char lbuff[LBUFLEN+1];
@@ -109,6 +108,7 @@ int main(int argc, char *argv[])
 	GThread *t1, *t2, *t3;
 	int s1, s2;
 	struct tparam th;
+	time_t timer;
 
 	/* initialize structure */
 	cf = (struct config *)malloc(sizeof(struct config));
@@ -171,11 +171,18 @@ int main(int argc, char *argv[])
 	th.auth_flag = 0;
 	th.regist_done = 0;
 	bzero(th.store_message, sizeof(th.store_message));
+	th.phone_carrier = OTHER; /* Other */
 
 	/* timer */
 	th.last_access = 0;
 	th.timeout = cf->timeout;
 
+	time(&timer);
+	th.last_check = timer;
+
+	/* version */
+	th.new_available = -1;
+
 	/* initialize memory allocate for send_buf */
 	th.send_buf = (char*)malloc(HTTPBUF * 2);
 	th.send_buflen = HTTPBUF * 2;
@@ -245,7 +252,7 @@ watch(gpointer param)
 	struct tparam *th;
 	struct timeval timeout;
 	fd_set *fdset;
-	int s, n;
+	int s;
 	char *sbuf;
 
 	th = (struct tparam *)param;
@@ -305,7 +312,7 @@ lineget(gpointer param)
 	int lcount = 0;
 	th = (struct tparam *)param;
 
-	printf("kircd ver %s\n", version);
+	printf("kircd ver %s\n", VERSION);
 
 	do {
 		if (th->s_empty || th->s_lock) {
@@ -336,8 +343,7 @@ lineget(gpointer param)
 		DPRINTF(2, ("s_empty=%d, s_lock=%d\n",
 			th->s_empty, th->s_lock));
 		DPRINTF(2, ("s_read=%d, s_count=%d\n",
-			th->s_read, th->s_count))
-;
+			th->s_read, th->s_count));
 		keitai_start(th);
 
 		/* buffer clear */
